<?php # lang_cz.inc.php 1501.1 2009-08-15 10:29:04 VladaAjgl $

/**
 *  @version 1501.1
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  Translated on 2007/11/30
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/05/06
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/08/15
 */

@define('PLUGIN_EVENT_NL2BR_NAME',              'Markup: NL2BR');
@define('PLUGIN_EVENT_NL2BR_DESC',              'Mn znaky konce dku na tagy <br />');
@define('PLUGIN_EVENT_NL2BR_ISOLATE_TAGS',      'Seznam html tag, uvnit kterch nemaj bt konce dk nahrazovny.');
@define('PLUGIN_EVENT_NL2BR_ISOLATE_TAGS_DESC', 'Nvrhy: "code,pre,geshi,textarea". Nzvy tag oddlujte rkou. Tip: Zadvan tagy jsou vyhodnocovny jako regulrn vraz.');
@define('PLUGIN_EVENT_NL2BR_PTAGS',              'Pout tagy &lt;p&gt;');
@define('PLUGIN_EVENT_NL2BR_PTAGS_DESC',              'Vkldat tagy &lt;p&gt; msto tag &lt;br /&gt;');